// Fig. 9.17: point3.h
// Point3 class definition represents an x-y coordinate pair.
#ifndef POINT3_H
#define POINT3_H

class Point3 {

public:
   Point3( int = 0, int = 0 ); // default constructor

   void setX( int );    // set x in coordinate pair
   int getX() const;    // return x from coordinate pair
   
   void setY( int );    // set y in coordinate pair
   int getY() const;    // return y from coordinate pair
   
   void print() const;  // output Point3 object

private: 
   int x;  // x part of coordinate pair
   int y;  // y part of coordinate pair

}; // end class Point3

#endif

/**************************************************************************
 * (C) Copyright 1992-2003 by Deitel & Associates, Inc. and Prentice      *
 * Hall. All Rights Reserved.                                             *
 *                                                                        *
 * DISCLAIMER: The authors and publisher of this book have used their     *
 * best efforts in preparing the book. These efforts include the          *
 * development, research, and testing of the theories and programs        *
 * to determine their effectiveness. The authors and publisher make       *
 * no warranty of any kind, expressed or implied, with regard to these    *
 * programs or to the documentation contained in these books. The authors *
 * and publisher shall not be liable in any event for incidental or       *
 * consequential damages in connection with, or arising out of, the       *
 * furnishing, performance, or use of these programs.                     *
 *************************************************************************/

// Fig. 9.19: circle4.h
// Circle4 class contains x-y coordinate pair and radius.
#ifndef CIRCLE4_H
#define CIRCLE4_H

#include "point3.h"  // Point3 class definition

class Circle4 {

public:

   // default constructor
   Circle4( int = 0, int = 0, double = 0.0 );  

   void setRadius( double );   // set radius
   double getRadius() const;   // return radius

   double getDiameter() const;       // return diameter
   double getCircumference() const;  // return circumference
   double getArea() const;           // return area

   void print() const;         // output Circle4 object

private: 
   double radius;  // Circle4's radius
   Point3 point;   // Create object of Point3 class

}; // end class Circle4

#endif 

/**************************************************************************
 * (C) Copyright 1992-2003 by Deitel & Associates, Inc. and Prentice      *
 * Hall. All Rights Reserved.                                             *
 *                                                                        *
 * DISCLAIMER: The authors and publisher of this book have used their     *
 * best efforts in preparing the book. These efforts include the          *
 * development, research, and testing of the theories and programs        *
 * to determine their effectiveness. The authors and publisher make       *
 * no warranty of any kind, expressed or implied, with regard to these    *
 * programs or to the documentation contained in these books. The authors *
 * and publisher shall not be liable in any event for incidental or       *
 * consequential damages in connection with, or arising out of, the       *
 * furnishing, performance, or use of these programs.                     *
 *************************************************************************/

// Fig. 9.22: cylinder.h
// Cylinder class inherits from class Circle4.
#ifndef CYLINDER_H
#define CYLINDER_H

#include "circle4.h"  // Circle4 class definition

class Cylinder{

public:

   // default constructor
   Cylinder( int = 0, int = 0, double = 0.0, double = 0.0 ); 
      
   void setHeight( double );  // set Cylinder's height
   double getHeight() const;  // return Cylinder's height 

   double getArea() const;    // return Cylinder's area
   double getVolume() const;  // return Cylinder's volume
   void print() const;        // output Cylinder

   double getCircumference() const
   {
	   return circle.getCircumference();
   }

private:
   double height;  // Cylinder's height
   Circle4 circle; // create an object of Circle4 class

}; // end class Cylinder

#endif

/**************************************************************************
 * (C) Copyright 1992-2003 by Deitel & Associates, Inc. and Prentice      *
 * Hall. All Rights Reserved.                                             *
 *                                                                        *
 * DISCLAIMER: The authors and publisher of this book have used their     *
 * best efforts in preparing the book. These efforts include the          *
 * development, research, and testing of the theories and programs        *
 * to determine their effectiveness. The authors and publisher make       *
 * no warranty of any kind, expressed or implied, with regard to these    *
 * programs or to the documentation contained in these books. The authors *
 * and publisher shall not be liable in any event for incidental or       *
 * consequential damages in connection with, or arising out of, the       *
 * furnishing, performance, or use of these programs.                     *
 *************************************************************************/

// Fig. 9.18: point3.cpp
// Point3 class member-function definitions.
#include <iostream>  

using std::cout;

#include "point3.h"   // Point3 class definition

// default constructor
Point3::Point3( int xValue, int yValue )
   : x( xValue ), y( yValue )
{
   // empty body 

} // end Point3 constructor

// set x in coordinate pair
void Point3::setX( int xValue )
{
   x = xValue; // no need for validation

} // end function setX

// return x from coordinate pair
int Point3::getX() const
{
   return x;

} // end function getX

// set y in coordinate pair
void Point3::setY( int yValue )
{
   y = yValue; // no need for validation

} // end function setY

// return y from coordinate pair
int Point3::getY() const
{
   return y;

} // end function getY
   
// output Point3 object
void Point3::print() const
{
   cout << '[' << getX() << ", " << getY() << ']';

} // end function print

/**************************************************************************
 * (C) Copyright 1992-2003 by Deitel & Associates, Inc. and Prentice      *
 * Hall. All Rights Reserved.                                             *
 *                                                                        *
 * DISCLAIMER: The authors and publisher of this book have used their     *
 * best efforts in preparing the book. These efforts include the          *
 * development, research, and testing of the theories and programs        *
 * to determine their effectiveness. The authors and publisher make       *
 * no warranty of any kind, expressed or implied, with regard to these    *
 * programs or to the documentation contained in these books. The authors *
 * and publisher shall not be liable in any event for incidental or       *
 * consequential damages in connection with, or arising out of, the       *
 * furnishing, performance, or use of these programs.                     *
 *************************************************************************/

// Fig. 9.20: circle4.cpp
// Circle4 class member-function definitions.
#include <iostream>  

using std::cout;

#include "circle4.h"   // Circle4 class definition

//Major change : Replace 'Point3' with 'point'an object of Circle4 class

// default constructor
Circle4::Circle4( int xValue, int yValue, double radiusValue )
   : point( xValue, yValue )  // call base-class constructor
{
   setRadius( radiusValue );

} // end Circle4 constructor

// set radius 
void Circle4::setRadius( double radiusValue )
{
   radius = ( radiusValue < 0.0 ? 0.0 : radiusValue );

} // end function setRadius

// return radius 
double Circle4::getRadius() const
{
   return radius;

} // end function getRadius

// calculate and return diameter
double Circle4::getDiameter() const
{
   return 2 * getRadius();

} // end function getDiameter

// calculate and return circumference
double Circle4::getCircumference() const
{
   return 3.14159 * getDiameter();

} // end function getCircumference

// calculate and return area
double Circle4::getArea() const
{
   return 3.14159 * getRadius() * getRadius();

} // end function getArea

// output Circle4 object
void Circle4::print() const
{
   cout << "Center = ";
   point.print();      // invoke Point3's print function
   cout << "; Radius = " << getRadius();

} // end function print

/**************************************************************************
 * (C) Copyright 1992-2003 by Deitel & Associates, Inc. and Prentice      *
 * Hall. All Rights Reserved.                                             *
 *                                                                        *
 * DISCLAIMER: The authors and publisher of this book have used their     *
 * best efforts in preparing the book. These efforts include the          *
 * development, research, and testing of the theories and programs        *
 * to determine their effectiveness. The authors and publisher make       *
 * no warranty of any kind, expressed or implied, with regard to these    *
 * programs or to the documentation contained in these books. The authors *
 * and publisher shall not be liable in any event for incidental or       *
 * consequential damages in connection with, or arising out of, the       *
 * furnishing, performance, or use of these programs.                     *
 *************************************************************************/

// Fig. 9.23: cylinder.cpp
// Cylinder class inherits from class Circle4.
#include <iostream>  

using std::cout;

#include "cylinder.h"   // Cylinder class definition


// Major change : Replace 'Circle4' with 'circle'an object of Circle4 class

// default constructor
Cylinder::Cylinder( int xValue, int yValue, double radiusValue, 
  double heightValue ) 
  : circle( xValue, yValue, radiusValue )
{
   setHeight( heightValue );

} // end Cylinder constructor

// set Cylinder's height
void Cylinder::setHeight( double heightValue )
{
   height = ( heightValue < 0.0 ? 0.0 : heightValue );

} // end function setHeight

// get Cylinder's height
double Cylinder::getHeight() const
{
   return height;

} // end function getHeight

// redefine Circle4 function getArea to calculate Cylinder area
double Cylinder::getArea() const
{
   return 2 * circle.getArea() + 
      getCircumference() * getHeight();

} // end function getArea

// calculate Cylinder volume
double Cylinder::getVolume() const
{
   return circle.getArea() * getHeight();

} // end function getVolume

// output Cylinder object
void Cylinder::print() const
{
   circle.print();
   cout << "; Height = " << getHeight();

} // end function print

/**************************************************************************
 * (C) Copyright 1992-2003 by Deitel & Associates, Inc. and Prentice      *
 * Hall. All Rights Reserved.                                             *
 *                                                                        *
 * DISCLAIMER: The authors and publisher of this book have used their     *
 * best efforts in preparing the book. These efforts include the          *
 * development, research, and testing of the theories and programs        *
 * to determine their effectiveness. The authors and publisher make       *
 * no warranty of any kind, expressed or implied, with regard to these    *
 * programs or to the documentation contained in these books. The authors *
 * and publisher shall not be liable in any event for incidental or       *
 * consequential damages in connection with, or arising out of, the       *
 * furnishing, performance, or use of these programs.                     *
 *************************************************************************/

#include <iostream>
<iostream>using std::cout; using std::endl; using std::fixed; 
<iomanip>using std::setprecision; 
#include "cylinder.h" 
int main() 
{ Point3 p( 8, 1 ); Circle4 c( 2.0, 9, 6); Cylinder cyl( 5.7, 2.5, 2, 5 ); 
  cout << "Point: " ; p.print(); cout <<endl >< "Circle: " ; c.print(); 
  cout <<endl >< "Cylinder: " ; cyl.print(); cout << endl; 
  return 0; 
} 
/* Output : Before Modifications: 
Point: [8, 1] Circle: Center = [2, 9]; Radius = 6 Cylinder: Center = [5, 2]; Radius = 2; Height = 5 Press any key to continue 
After Modifications: 
Point: [8, 1] Circle: Center = [2, 9]; Radius = 6 Cylinder: Center = [5, 2]; Radius = 2; Height = 5 Press any key to continue */

